FixtureCommand

Enum FixtureCommand 

pub(super) enum FixtureCommand {
    SpawnFixture {
        name: String,
        fixture_type_name: String,
        start_channel: ChannelIndex,
        start_universe: usize,
        reply_to: Sender<Result<(), FixtureError>>,
    },
    MoveFixture {
        name: String,
        new_channel: ChannelIndex,
        new_universe: usize,
        reply_to: Sender<Result<(), FixtureError>>,
    },
    RemoveFixture {
        name: String,
        reply_to: Sender<Result<(), FixtureError>>,
    },
    SetProperty {
        fixture_name: String,
        property: PropertyType,
        value: ChannelValue,
        reply_to: Sender<Result<(), FixtureError>>,
    },
    GetType {
        fixture_name: String,
        reply_to: Sender<Result<String, FixtureError>>,
    },
}
Commands sent asynchronously to the fixture engine thread to manage fixture instances and modify their properties or states.

Variants



SpawnFixture

Spawns a new fixture instance with a given type, start address, and universe.

Fields

name: String

Unique name for the new fixture instance.

fixture_type_name: String

Name of the registered FixtureType template to use.

start_channel: ChannelIndex

Starting DMX-Channel index within the universe.

start_universe: usize

DMX universe index (0-based) where the fixture resides.

reply_to: Sender<Result<(), FixtureError>>

Sender channel used to reply with the success or failure result.



MoveFixture

Moves an existing fixture to a new DMX channel and/or universe and changes the reserved channels accordingly

Fields

name: String

Name of the fixture to move.

new_channel: ChannelIndex

New starting DMX channel index.

new_universe: usize

New target DMX universe index.

reply_to: Sender<Result<(), FixtureError>>

Sender channel used to reply with the success or failure result.



RemoveFixture

Removes an existing fixture instance and frees its reserved channels.

Fields

name: String

Name of the fixture to remove.

reply_to: Sender<Result<(), FixtureError>>

Sender channel used to reply with the success or failure result.



SetProperty

Sets a specific property value on a target fixture.

Fields

fixture_name: String

Name of the target fixture.

property: PropertyType

The property type to modify (Simple or Color).

value: ChannelValue

The new channel value to assign.

reply_to: Sender<Result<(), FixtureError>>

Sender channel used to reply with the success or failure result.



GetType

Retrieves the fixture type name for a given fixture.

Fields

fixture_name: String

Name of the target fixture.

reply_to: Sender<Result<String, FixtureError>>

Sender channel used to reply with the fixture type name string or an error.